#!/usr/bin/env python
# -*- coding: UTF-8 -*-
"""
Пример 2 к статье "Построение графиков с помощью matplotlib и pyGTK."
Автор: Попов О.Б.,
2007г.
"""
import pygtk
pygtk.require('2.0')
import gtk
from matplotlib.axes import Subplot
from matplotlib.figure import Figure,SubplotParams
from matplotlib.numerix import arange, sin,  pi,cos,exp,multiply
from matplotlib.backends.backend_gtkagg  import FigureCanvasGTKAgg as FigureCanvas
from matplotlib.backends.backend_gtk  import NavigationToolbar2GTK as NavigationToolbar
#цвета 
cl_background='#E8D6BB'#фон
cl_grid='#330000'#линии сетки
cl_bars=('#330000','#660000','#993300','#996600','#CC6600','#CC6666','#CC9900',
'#CC9966','#CCCC99','#CCCC00','#C9A24B','#94AB27','#8A8B75','#8A725E','#A080A4',
'#9C8BBF','#969CE7','#976CD1','#983BBA','#A92998','#AAAA9A','#EFBEAA','#CCCC66')


OilReservesbyCountry=(('Saudi Arabia',264.3),('Canada',178.8),('Iran',132.5),('Iraq',115.0),
('Kuwait',101.5),('UAE',97.8),('Venezuela',79.7),('Russia',60.0),('Libya',39.1),('Nigeria',35.9),
('United States',21.4),('China',18.3),('Qatar',15.2),('Mexico',12.9),('Algeria',11.4),('Brazil',11.2),
('Kazakhstan',9.0),('Norway',7.7),('Azerbaijan',7.0),('India',5.8),('Rest of World',68.1))

CrudeOilProduction2005=(('Saudi Arabia',9.55),('Canada',2.37),('Iran',4.14),('Iraq',1.88),
('Kuwait',2.53),('UAE',2.54),('Venezuela',2.57),('Russia',9.07),
('Nigeria',2.63),('United States',5.12),('China',3.61),('Mexico',3.33),
('Norway',2.70),('United Kingdom',1.65))

RussiaPartOilReserves=(60.0,1292.5-60.0)
RussiaPartOilProduction2005=(9.07,73.58-9.07)

class OilPlotDemo:
    def __init__(self):
        # Создаём новое окно
        self.window = gtk.Window(gtk.WINDOW_TOPLEVEL) 
        # Заголовок окна
        self.window.set_title(" Пример построения диаграмм с помощью matplotlib")
        self.window.set_border_width(8)#  размер рамки
        self.window.set_default_size(800,600)# размер окна
        # callback для события delete
        self.window.connect("delete_event", self.delete_event)
        self.window.connect("destroy", self.destroy) # callback
        self.vbox1 = gtk.VBox(False, 0)
        self.window.add (self.vbox1)
        #создать диаграмму
        self.figure1 = Figure(figsize=(12,12), dpi=68,facecolor=cl_background)
        self.draw_barchart(1,u' Мировые запасы нефти на 1 января 2006 года',
        OilReservesbyCountry,   u'миллиарды баррелей')
        self.draw_barchart(2,u'Добыча сырой нефти в 2005 году',
        CrudeOilProduction2005,  u'миллионы баррелей/сутки')
        self.draw_piechart1()
        self.draw_piechart2()
        #scrolled window 
        self.scrolledwindow1 = gtk.ScrolledWindow()
        self.scrolledwindow1.show ()
        self.vbox1.pack_start (self.scrolledwindow1, True,True, 0)
        self.scrolledwindow1.set_border_width ( 8)
        # "запаковать" диграмму внутрь gtk.DrawingArea
        self.canvas = FigureCanvas(self.figure1)
         # минимальнй размер области рисования
        self.canvas.set_size_request(700,500)
        self.scrolledwindow1.add_with_viewport(self.canvas)
        #добавляем  toolbar
        self.toolbar = NavigationToolbar(self.canvas, self.window)
        self.vbox1.pack_start(	self.toolbar, False, False)
        self.window.show_all()
        
    def draw_barchart(self,NumChart,Title,DataSource,YLabel ):
        '''метод  создаёт столбцовую диаграмму
        параметры :
        numChart	 - номер диаграммы
        Title- заголовок
        DataSource- исходные данные
        YLabel-метка для оси  Y		
        '''
        self.subplot=self.figure1.add_subplot(2,2,NumChart,axisbg=cl_background)
        self.figure1.subplots_adjust(left=0.1,bottom=0.05,hspace=0.9)
        self.subplot.set_title(Title,fontsize=14)
        #массивы значений для оси X
        X=arange(len(DataSource))
        dataY=[x[1] for x in DataSource ]
        width = 0.75
        barchart= self.subplot.bar(X, dataY, width)
        #координатную сетку на задний план
        self.subplot.set_axisbelow(True)
        #координатную сетку на задний план
        self.subplot.grid(True)
        # Максимальные и минимальные значения по оси X
        self.subplot.set_xlim(-1,len(X)+1)
        # Список меток оси х
        labels=[x[0] for x in DataSource] 
        #  Местополжение меток строго по центру столбца
        self.subplot.set_xticks(X+width/2.,) 
        #установить метки для оси X, повернуть их на 90 градусов
        self.subplot.set_xticklabels(labels,rotation=90) 
        self.subplot.set_ylabel(YLabel)  #название оси Y
        indcolor=0 
        for bar in barchart:
            bar.set_facecolor(cl_bars[indcolor])
            indcolor=indcolor+1
    #	
    def draw_piechart1(self):
        self.subplot3=self.figure1.add_subplot(2,2,3)#
        self.subplot3.set_title(u'Доля России в мировых запасах',fontsize=14)
        self.subplot3.pie(RussiaPartOilReserves,labels=(u'Россия',u'прочие\n страны '),
        autopct = '%1.1f%%',explode=(0.2,0.2),
        colors=('#C9A24B','#CCCC99'),shadow=True)
        self.subplot4=self.figure1.add_subplot(2,2,4)#
    def draw_piechart2(self):
        self.subplot4=self.figure1.add_subplot(2,2,4)#
        self.subplot4.set_title(u'Доля России в мировой добыче ',fontsize=14)
        self.subplot4.pie(RussiaPartOilProduction2005,
        labels=(u'Россия',u'прочие\n страны '),
        autopct = '%1.1f%%',explode=(0.1,0.1),
        colors=('#C9A24B','#CCCC99'),shadow=True)
    #Callbacks:
    def destroy(self, widget,data=None):
        gtk.main_quit()
    def delete_event(self, widget, event, data=None):
        return False	      

SimplePlotDemApp=OilPlotDemo()
gtk.main()
